@@ -108,7 +108,13 @@ new_request <- function(client, operation, params, data) {
     method <- "POST"
   }
 
-  http_req <- new_http_request(method, "", NULL, client$config$timeout)
+  http_req <- new_http_request(
+    method = method,
+    url = "",
+    body = NULL,
+    close = client$config$close_connection,
+    timeout = client$config$timeout
+  )
 
   http_req$url <- parse_url(
     paste0(client$client_info$endpoint, operation$http_path)
